mafw.active
===========

.. automodule:: mafw.active

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      ActiveType
      ActivableType
   
   .. rubric:: Classes

   .. autosummary::
   
      Active
   